==> haskell-hsyaml-aeson-0.2.0.2-50.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.2
visibility:           public
id:                   HsYAML-aeson-0.2.0.2-LF8EqBS47OaA4KQXvZYcZL
key:                  HsYAML-aeson-0.2.0.2-LF8EqBS47OaA4KQXvZYcZL
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  966a1a67e08e7498a658d8d7dad76910
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.2-LF8EqBS47OaA4KQXvZYcZL
depends:
    HsYAML-0.2.1.5-LCvWSQv2Ku5HL4QY5OHlCf
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-aeson-0.2.0.2-51-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.2
visibility:           public
id:                   HsYAML-aeson-0.2.0.2-4CWU1VzZuSk4saVKtjHz33
key:                  HsYAML-aeson-0.2.0.2-4CWU1VzZuSk4saVKtjHz33
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  fa9679ddba7c37e7454a7a318ab01a53
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.2-4CWU1VzZuSk4saVKtjHz33
depends:
    HsYAML-0.2.1.5-5ALdEUiBZBy68ckkwtJ8RG
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
